==> eiffelstudio-18.07.10.1981.tar: F_code/C14/xm686.c <==
/*
 * Code for class XM_XSLT_STYLESHEET_FUNCTION_LIBRARY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm686.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XSLT_STYLESHEET_FUNCTION_LIBRARY}.make */
void F1548_13227 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
{
	GTCX
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) arg2;
	RTLE;
}

/* {XM_XSLT_STYLESHEET_FUNCTION_LIBRARY}.is_function_available */
EIF_BOOLEAN F1548_13228 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_BOOLEAN arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	if ((EIF_BOOLEAN) !arg3) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc1 = F2076_21039(RTCW(tr1), arg1, arg2);
		Result = '\0';
		if ((EIF_BOOLEAN)(loc1 != NULL)) {
			tb1 = *(EIF_BOOLEAN *)(RTCW(loc1)+ _CHROFF_29_8_);
			Result = (EIF_BOOLEAN)(tb1 == *(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_));
		}
	}
	RTLE;
	return Result;
}

/* {XM_XSLT_STYLESHEET_FUNCTION_LIBRARY}.bind_function */
void F1548_13230 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_REFERENCE arg2, EIF_BOOLEAN arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc3);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,arg2);
	RTLR(4,loc1);
	RTLR(5,loc2);
	RTLIU(6);
	
	RTGC;
	RTCT0(NULL, EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg2)+ _LNGOFF_4_0_0_1_);
	tr1 = F2076_21039(RTCW(tr1), arg1, ti4_1);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		RTCK0;
	} else {
		RTCF0;
	}
	loc1 = (EIF_REFERENCE) loc3;
	tr1 = RTLNS(eif_new_type(1848, 0x00).id, 1848, _OBJSIZ_11_40_0_4_0_0_0_0_);
	F1849_18721(RTCW(tr1), arg1, arg2);
	loc2 = (EIF_REFERENCE) tr1;
	RTAR(Current, loc2);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc2;
	F2116_21673(RTCW(loc1), loc2);
	RTLE;
}

/* {XM_XSLT_STYLESHEET_FUNCTION_LIBRARY}.stylesheet */
EIF_REFERENCE F1548_13231 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


void EIF_Minit686 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C14/xm686.c <==
/*
 * Code for class XM_XSLT_STYLESHEET_FUNCTION_LIBRARY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm686.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XSLT_STYLESHEET_FUNCTION_LIBRARY}.make */
void F1549_13262 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
{
	GTCX
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_) = (EIF_BOOLEAN) arg2;
	RTLE;
}

/* {XM_XSLT_STYLESHEET_FUNCTION_LIBRARY}.is_function_available */
EIF_BOOLEAN F1549_13263 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_BOOLEAN arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	if ((EIF_BOOLEAN) !arg3) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc1 = F2078_21079(RTCW(tr1), arg1, arg2);
		Result = '\0';
		if ((EIF_BOOLEAN)(loc1 != NULL)) {
			tb1 = *(EIF_BOOLEAN *)(RTCW(loc1)+ _CHROFF_29_8_);
			Result = (EIF_BOOLEAN)(tb1 == *(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_));
		}
	}
	RTLE;
	return Result;
}

/* {XM_XSLT_STYLESHEET_FUNCTION_LIBRARY}.bind_function */
void F1549_13265 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_REFERENCE arg2, EIF_BOOLEAN arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc3);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,arg2);
	RTLR(4,loc1);
	RTLR(5,loc2);
	RTLIU(6);
	
	RTGC;
	RTCT0("attached stylesheet.stylesheet_function (a_fingerprint, some_arguments.count) as l_stylesheet_function", EX_CHECK);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg2)+ _LNGOFF_4_0_0_1_);
	tr1 = F2078_21079(RTCW(tr1), arg1, ti4_1);
	loc3 = tr1;
	if (EIF_TEST(loc3)) {
		RTCK0;
	} else {
		RTCF0;
	}
	loc1 = (EIF_REFERENCE) loc3;
	tr1 = RTLNS(eif_new_type(1850, 0x00).id, 1850, _OBJSIZ_11_40_0_4_0_0_0_0_);
	F1851_18761(RTCW(tr1), arg1, arg2);
	loc2 = (EIF_REFERENCE) tr1;
	RTAR(Current, loc2);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc2;
	F2118_21713(RTCW(loc1), loc2);
	RTLE;
}

/* {XM_XSLT_STYLESHEET_FUNCTION_LIBRARY}.stylesheet */
EIF_REFERENCE F1549_13266 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


void EIF_Minit686 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
